import { useState, KeyboardEvent } from 'react'
import { Button, Card, FloatButton, Select } from 'antd'
import { CircleArrowLeft, CircleArrowRight } from 'lucide-react'
import './AIChat.scss'
import { OpenAIOutlined, SendOutlined } from '@ant-design/icons'
import TextArea from 'antd/es/input/TextArea'
import { useAI } from '@/hooks/useAI'
import Markdown from 'react-markdown'
import remarkGfm from 'remark-gfm'

export default function AIChat() {
  const [collapsed, setCollapsed] = useState(false)

  const toggleCollapsed = () => {
    setCollapsed(!collapsed)
  }

  const { ai, setAI, options, post, messages, isLoading } = useAI()

  const [content, setContent] = useState('')

  const handleEnterSearch = (e: KeyboardEvent<HTMLTextAreaElement>) => {
    if (e.key === 'Enter' && !e.shiftKey) {
      e.preventDefault()
      handleSearch()
    }
  }
  const handleSearch = () => {
    setContent('')
    post({ content })
  }

  const messageItemRender = (message) => {
    return (
      <div className={`message-item ${message.role}`}>
        <div className="message-box">
          <div className="message-content">
            <Markdown remarkPlugins={[remarkGfm]}>{message.content}</Markdown>
          </div>
        </div>
      </div>
    )
  }

  if (collapsed) {
    return (
      <Card
        className="app-card ai-chat"
        title="AI对话"
        extra={<span onClick={toggleCollapsed}>{collapsed ? <CircleArrowRight /> : <CircleArrowLeft />}</span>}>
        <div className="ai-chat-container">
          <div className="message-scroll">
            {messages.map((message) => {
              return messageItemRender(message)
            })}
          </div>
          <Select value={ai} options={options} onChange={setAI} style={{ width: '100%' }}></Select>
          <div className="input-container">
            <div className="input-box">
              <div className="edit-area">
                <TextArea
                  className="content"
                  autoSize
                  value={content}
                  placeholder="今天需要我做些什么？shift+enter换行"
                  onChange={(e) => setContent(e.target.value)}
                  onKeyDown={handleEnterSearch}
                />
              </div>
              <div className="input-tools">
                <Button
                  type="primary"
                  size="large"
                  icon={<SendOutlined />}
                  onClick={handleSearch}
                  loading={isLoading}
                />
              </div>
            </div>
            <div className="upload-list"></div>
          </div>
        </div>
      </Card>
    )
  } else {
    return <FloatButton icon={<OpenAIOutlined />} onClick={toggleCollapsed} />
  }
}
