import { useEffect } from 'react'
import { useQuery } from '@tanstack/react-query'
import { getUser, getMapList } from '@/api/base'
import { useUserStore } from '@/stores/user'
import { useMapStore } from '@/stores/map'

export function useUserQuery() {
  const { setUser } = useUserStore()

  const query = useQuery({ queryKey: ['user'], queryFn: getUser, select: (res) => res.data })

  useEffect(() => {
    if (query.data) {
      setUser(query.data)
    }
  }, [query.data, setUser])

  return query
}

export function useMapQuery() {
  const { setMap } = useMapStore()

  const query = useQuery({ queryKey: ['dictionary'], queryFn: getMapList, select: (res) => res.data })

  useEffect(() => {
    if (query.data) {
      setMap(query.data)
    }
  }, [query.data, setMap])

  return query
}
