import { lazy, useState } from 'react'
import { Button, Card, Input, Select } from 'antd'
import AppList, { AppListProps } from '@/components/AppList'
import { useMapStore } from '@/stores/map'

const FormModal = lazy(() => import('../components/FormModal'))
const ViewDataModal = lazy(() => import('@/components/data/ViewDataModal'))

export default function DataWriteBuilt() {
  const getMapValuesByKey = useMapStore((state) => state.getMapValuesByKey)
  const industryList = getMapValuesByKey('bi_data_industry')

  const [isModalOpen, setIsModalOpen] = useState(false)

  const showModal = () => {
    setIsModalOpen(true)
  }

  const handleOk = () => {
    setIsModalOpen(false)
  }

  const handleCancel = () => {
    setIsModalOpen(false)
  }

  const [viewModalIsOpen, setViewModalIsOpen] = useState(false)

  const handleView = (record: any) => {
    console.log(record)
    setViewModalIsOpen(true)
  }

  const handleRemove = (record: any) => {
    console.log(record)
  }

  const listOptions: AppListProps = {
    filters: [
      {
        name: 'industry',
        element: <Select placeholder="请选择所属行业" options={industryList} />,
      },
      {
        name: 'name',
        element: <Input placeholder="请输入数据集名称" />,
      },
    ],
    columns: [
      {
        title: '序号',
        key: 'index',
        render(_value, _record, index) {
          return index + 1
        },
        width: 62,
        align: 'center',
      },
      { title: '数据集名称', dataIndex: 'name' },
      { title: '数据量', dataIndex: 'count' },
      { title: '所属行业', dataIndex: 'industry' },
      { title: '数据来源', dataIndex: 'sourc' },
      { title: '敏感等级', dataIndex: 'level' },
      { title: '访问权限', dataIndex: 'auth' },
      { title: '说明', dataIndex: 'desc' },
      { title: '创建人', dataIndex: 'create' },
      { title: '创建时间', dataIndex: 'create_time' },
      { title: '更新时间', dataIndex: 'update_time' },
      {
        title: '操作',
        key: 'x',
        width: 160,
        align: 'center',
        render(_value, record) {
          return (
            <>
              <Button color="primary" variant="text" onClick={() => handleView(record)}>
                查阅
              </Button>
              <Button color="danger" variant="text" onClick={() => handleRemove(record)}>
                删除
              </Button>
            </>
          )
        },
      },
    ],
    dataSource: [
      { id: 1, name: '《商务数据分析基础》数据集' },
      { id: 2, name: '智慧交通数据集' },
      { id: 3, name: '信用卡数字营销数据集' },
    ],
  }
  return (
    <Card className="app-card" title="内置数据集管理">
      <AppList
        bordered
        {...listOptions}
        filterAside={
          <Button type="primary" onClick={showModal}>
            添加数据集
          </Button>
        }></AppList>

      <FormModal open={isModalOpen} onOk={handleOk} onCancel={handleCancel}></FormModal>

      <ViewDataModal open={viewModalIsOpen} onCancel={() => setViewModalIsOpen(false)}></ViewDataModal>
    </Card>
  )
}
