import { Button, Card, Input, Select } from 'antd'
import AppList, { AppListProps } from '@/components/AppList'
import { useMapStore } from '@/stores/map'
import { lazy, useState } from 'react'

const CopyModal = lazy(() => import('../components/CopyModal'))
const ViewDataModal = lazy(() => import('@/components/data/ViewDataModal'))

export default function DataWriteCopy() {
  const getMapValuesByKey = useMapStore((state) => state.getMapValuesByKey)
  const industryList = getMapValuesByKey('bi_data_industry')

  const generateDataSource = (count: number) => {
    return Array.from({ length: count }, (_, index) => ({
      id: index,
      key: index,
      name: `数据集名称 ${index + 1}`,
      count: Math.floor(Math.random() * 1000),
      industry: `行业 ${index + 1}`,
      source: `来源 ${index + 1}`,
      level: `等级 ${index + 1}`,
      auth: `权限 ${index + 1}`,
      desc: `说明 ${index + 1}`,
      create: `创建人 ${index + 1}`,
      create_time: new Date().toLocaleString(),
      update_time: new Date().toLocaleString(),
    }))
  }

  const [viewModalIsOpen, setViewModalIsOpen] = useState(false)

  const handleView = (record: any) => {
    console.log(record)
    setViewModalIsOpen(true)
  }

  const [copyModalIsOpen, setCopyModalIsOpen] = useState(false)
  const handleCopy = (record: any) => {
    console.log(record)
    setCopyModalIsOpen(true)
  }

  const listOptions: AppListProps = {
    filters: [
      {
        name: 'industry',
        element: <Select placeholder="请选择所属行业" options={industryList} />,
      },
      {
        name: 'name',
        element: <Input placeholder="请输入数据集名称" />,
      },
    ],
    columns: [
      {
        title: '序号',
        key: 'index',
        render(_value, _record, index) {
          return index + 1
        },
        width: 62,
        align: 'center',
      },
      { title: '数据集名称', dataIndex: 'name', align: 'center' },
      { title: '数据量', dataIndex: 'count', align: 'center' },
      { title: '所属行业', dataIndex: 'industry', align: 'center' },
      { title: '数据来源', dataIndex: 'source', align: 'center' },
      { title: '敏感等级', dataIndex: 'level', align: 'center' },
      { title: '访问权限', dataIndex: 'auth', align: 'center' },
      { title: '说明', dataIndex: 'desc', align: 'center' },
      { title: '创建人', dataIndex: 'create', align: 'center' },
      { title: '创建时间', dataIndex: 'create_time', align: 'center' },
      { title: '更新时间', dataIndex: 'update_time', align: 'center' },
      {
        title: '操作',
        key: 'x',
        width: 160,
        align: 'center',
        render(_value, record) {
          return (
            <>
              <Button color="primary" variant="text" onClick={() => handleView(record)}>
                查阅
              </Button>
              <Button color="primary" variant="text" onClick={() => handleCopy(record)}>
                复制
              </Button>
            </>
          )
        },
      },
    ],
    dataSource: generateDataSource(20),
  }
  return (
    <Card className="app-card" title="数据复制">
      <AppList bordered {...listOptions}></AppList>
      <CopyModal open={copyModalIsOpen} onCancel={() => setCopyModalIsOpen(false)}></CopyModal>
      <ViewDataModal open={viewModalIsOpen} onCancel={() => setViewModalIsOpen(false)}></ViewDataModal>
    </Card>
  )
}
